
SITE_ROOT_DEFAULT = "https://thedailydialectics.com"

SKIP_DIRS = frozenset({
    "text", "pages", "pdf_pages",
    "preprocessed_images", "preprocessed_text",
    "node_modules", ".git", "__pycache__",
})

IMAGE_EXTS = frozenset({".webp", ".jpg", ".jpeg", ".png", ".gif"})

